@@ -1,3 +1,18 @@
+if(FALSE) {
+.First.lib <-
+function(libname, pkgname)
+{
+ library.dynam("XML", pkgname, libname)
+
+ if(.useNamespacesInXMLPackage && exists("setMethod")) {
+   .InitSAXMethods()
+ }
+
+   # Set the error handlers to our local ones.
+ .C("RSXML_setErrorHandlers", PACKAGE = "XML")
+}
+}
+
 .onLoad =
 function(libname, pkgname)
 {
